#[non_exhaustive]pub enum Request<'a> {
SetSelection {
source: Option<ZwpPrimarySelectionSourceV1>,
serial: u32,
},
Destroy,
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
SetSelection
set the primary selection
Replaces the current selection. The previous owner of the primary selection will receive a wp_primary_selection_source.cancelled event.
To unset the selection, set the source to NULL.
Fields

source: Option<ZwpPrimarySelectionSourceV1>Destroy
destroy the primary selection device
Destroy the primary selection device.
This is a destructor, once sent this object cannot be used any longer.
Implementations